describe('Mercury Editor Templates e2e tests.', () => {

  before(() => {
    // Install the Mercury Editor Templates test module.
    cy.drush('en -y mercury_editor_templates_test');
    cy.drush('en -y mercury_editor_translations_test');
    cy.loginUserByUid(1);
    cy.visit('/admin/config/regional/language')
    cy.intercept('GET', '/admin/config/regional/language').as('addLanguage');

    cy.enableLanguage('es');
    cy.enableLanguage('de');
    cy.visit('/user/logout');
  });

  after(() => {
  });

  beforeEach(() => {
    cy.loginUserByUid(1);
  });

  it('tests asymetric translations with Mercury Editor', () => {

    cy.visit('/admin/config/regional/content-language');
    cy.get('#edit-entity-types-node').check();
    cy.get('#edit-entity-types-paragraph').uncheck();
    cy.get('#edit-settings-node-me-test-ct-translatable').check();

    // Paragraph field IS translatable == asymetric translations.
    cy.get('#edit-settings-node-me-test-ct-fields-field-me-test-content').should('be.checked');
    cy.get('#edit-submit').click();

    cy.visit('/node/add/me_test_ct');
    cy.meAddComponent('me_test_section');
    cy.meChooseLayout('layout_twocol');
    cy.meSaveComponent().then((section) => {
    cy.meAddComponent('me_test_text', {
        region: 'first',
        section
      });
      cy.meSetCKEditor5Value('field_me_test_text', 'Left (EN)');
      cy.meSaveComponent().then((component) => {
        cy.iframe('#me-preview').find(component).should('contain', 'Left (EN)');
      });

      cy.meAddComponent('me_test_text', {
        region: 'second',
        section
      });
      cy.meSetCKEditor5Value('field_me_test_text', 'Right (EN)');
      cy.meSaveComponent().then((component) => {
        cy.iframe('#me-preview').find(component).should('contain', 'Right (EN)');
      });
    });
    cy.meSavePage();
    cy.meExitEditor();

    cy.get('.tabs').find('a').contains('Translate').click();
    cy.get('a[hreflang="es"]').click();
    cy.meFindComponent(2).then((component) => {
      cy.meEditComponent(component);
      cy.meSetCKEditor5Value('field_me_test_text', 'Left (ES)');
      cy.meSaveComponent();
    });
    cy.meFindComponent(3).then((component) => {
      cy.meEditComponent(component);
      cy.meSetCKEditor5Value('field_me_test_text', 'Right (ES)');
      cy.meSaveComponent();
    });
    cy.meFindComponent(1).then((component) => {
      cy.meAddComponent('me_test_text', {
        region: 'bottom',
        section: component
      });
      cy.meSetCKEditor5Value('field_me_test_text', 'Footer Component (ES)');
      cy.meSaveComponent().then((component) => {
        cy.iframe('#me-preview').find(component).should('contain', 'Footer Component (ES)');
      });
    })

    cy.meSavePage();
    cy.meExitEditor();

    cy.get('.tabs').find('a').contains('Traducir').click();
    cy.get('a[hreflang="de"]').click();

    cy.meFindComponent(1).then((component) => {
      cy.meDeleteComponent(component);
      cy.meAddComponent('me_test_text');
      cy.meSetCKEditor5Value('field_me_test_text', 'Content Component (DE)');
      cy.meSaveComponent();
    });
    cy.meSavePage();
    cy.meExitEditor();

    cy.url().then(url => {
      const nid = url.match(/node\/(\d+)/)[1];

      cy.visit(`/node/${nid}`);
      cy.get('html').should('contain', 'Left (EN)');
      cy.get('html').should('contain', 'Right (EN)');
      cy.get('html').should('contain', 'Paragraph Language: en');

      cy.visit(`/es/node/${nid}`);
      cy.get('html').should('contain', 'Left (ES)');
      cy.get('html').should('contain', 'Right (ES)');
      cy.get('html').should('contain', 'Footer Component (ES)');
      cy.get('html').should('contain', 'Paragraph Language: es');

      cy.visit(`/de/node/${nid}`);
      cy.get('html').should('contain', 'Content Component (DE)');
      cy.get('html').should('contain', 'Paragraph Language: de');

      cy.visit(`/node/${nid}/delete`);
      cy.get('#edit-submit').click();
    })

  });

  it('tests symetric translations with Mercury Editor', () => {

    cy.visit('/admin/config/regional/content-language');
    cy.get('#edit-entity-types-node').check();
    cy.get('#edit-entity-types-paragraph').check();
    cy.get('#edit-settings-node-me-test-ct-fields-field-me-test-content').uncheck();
    cy.get('#edit-settings-node-me-test-ct-translatable').check();
    cy.get('#edit-settings-paragraph input.form-checkbox').check();
    cy.get('#edit-submit').click();

    cy.visit('/node/add/me_test_ct');
    cy.meAddComponent('me_test_text');
    cy.meSetCKEditor5Value('field_me_test_text', 'Content (EN)');
    cy.meSaveComponent();
    cy.meSavePage();
    cy.meExitEditor();

    cy.get('.tabs').find('a').contains('Translate').click();
    cy.get('a[hreflang="es"]').click();
    cy.meFindComponent(1).then((component) => {
      cy.meEditComponent(component);
      cy.meSetCKEditor5Value('field_me_test_text', 'Content (ES)');
      cy.meSaveComponent();
    });
    cy.meSavePage();
    cy.meExitEditor();

    cy.url().then(url => {
      const nid = url.match(/node\/(\d+)/)[1];
      cy.visit(`/node/${nid}`);
      cy.get('html').should('contain', 'Content (EN)');
      cy.get('div.me-test-paragraph-id').invoke('text').then(englishId => {
        cy.visit('/es/node/' + nid);
        cy.get('div.me-test-paragraph-id').invoke('text').then(spanishId => {
          expect(spanishId).to.equal(englishId);
          cy.get('html').should('contain', 'Content (ES)');
        });
      });
    });


  });

});
